#ifndef ARCCLI
#define ARCCLI

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string>
#include <list>

#include <arc/error.h>


/* constants for the whichfile argument to arccat */
#define STDOUT 0
#define STDERR 1
#define GMLOG 2


class ARCCLIError : public ARCLibError {
	public:
		ARCCLIError (std::string message) : ARCLibError(message) {}
};


void arccat (const std::list<std::string>& jobs,
             const std::list<std::string>& clusterselect,
             const std::list<std::string>& clusterreject,
             const std::list<std::string>& status,
             const int whichfile = STDOUT,
             const int timeout = 0,
             const bool anonymous = false);

void arcclean (const std::list<std::string>& jobs,
               const std::list<std::string>& clusterselect,
               const std::list<std::string>& clusterreject,
               const std::list<std::string>& status,
               const bool force = false,
               const int timeout = 0,
               const bool anonymous = false);

void arcget (const std::list<std::string>& jobs,
             const std::list<std::string>& clusterselect,
             const std::list<std::string>& clusterreject,
             const std::list<std::string>& status,
             const std::string& directory,
             const bool usejobname = false,
             const bool keep = false,
             const int timeout = 0,
             const bool anonymous = false);

void arckill (const std::list<std::string>& jobs,
              const std::list<std::string>& clusterselect,
              const std::list<std::string>& clusterreject,
              const std::list<std::string>& status,
              const bool keep = false,
              const int timeout = 0,
              const bool anonymous = false);

void arcrenew (const std::list<std::string>& jobs,
               const std::list<std::string>& clusterselect,
               const std::list<std::string>& clusterreject,
               const std::list<std::string>& status,
               const int timeout = 0,
               const bool anonymous = false);

void arcresub (const std::list<std::string>& jobs,
               const std::list<std::string>& clusterselect,
               const std::list<std::string>& clusterreject,
               const std::list<std::string>& status,
               const std::list<std::string>& klusterselect,
               const std::list<std::string>& klusterreject,
               const std::list<std::string>& giisurls,
               const std::string& joblistfile,
               const bool dryrun = false,
               const bool dumpxrsl = false,
               const bool keep = false,
               const int timeout = 0,
               const bool anonymous = false);

void arcresume (const std::list<std::string>& jobs,
                const std::list<std::string>& clusterselect,
                const std::list<std::string>& clusterreject,
                const std::list<std::string>& status,
                const bool renewproxy = false,
                const int timeout = 0,
                const bool anonymous = false);

void arcstat (const std::list<std::string>& jobs,
              const std::list<std::string>& clusterselect,
              const std::list<std::string>& clusterreject,
              const std::list<std::string>& status,
              const std::list<std::string>& giisurls,
              const bool clusters = false,
              const bool longlist = false,
              const int timeout = 0,
              const bool anonymous = false);

std::list<std::string> arcsub (const std::list<std::string>& xrslfiles,
                               const std::list<std::string>& xrslstrings,
                               const std::list<std::string>& clusterselect,
                               const std::list<std::string>& clusterreject,
                               const std::list<std::string>& giisurls,
                               const std::string& joblistfile,
                               const bool dryrun = false,
                               const bool dumpxrsl = false,
                               const int timeout = 0,
                               const bool anonymous = false);

void arcsync (const std::list<std::string>& clusterselect,
              const std::list<std::string>& clusterreject,
              const std::list<std::string>& giisurls,
              const bool force = false,
              const int timeout = 0,
              const bool anonymous = false);

void arctest (const unsigned int testjob,
              const bool certificateinfo,
              const bool voinfo,
              const bool resourceinfo,
              const bool configuration,
              const unsigned int runtime,
              const std::list<std::string>& clusterselect,
              const std::list<std::string>& clusterreject,
              const std::list<std::string>& giisurls,
              const std::string& joblistfile,
              const bool dryrun = false,
              const bool dumpxrsl = false,
              const int timeout = 0,
              const bool anonymous = false);


#endif
